# pySLiM

`pyslim` is a python module to allow reading and writing of SLiM-produced tree sequences
as a thin interface to [tskit](https://tskit.readthedocs.io/en/latest).
Please see [our documentation](https://pyslim.readthedocs.io/en/latest/) for more information.

## Installation

To install `pyslim`, do
```
pip install pyslim
```

<a href='https://pyslim.readthedocs.io/en/latest/?badge=latest'>
    <img src='https://readthedocs.org/projects/pyslim/badge/?version=latest' alt='Documentation Status' />
</a>
